@@ -20,7 +20,7 @@ class CLI:
                 0  # want current value, shellcon.SHGFP_TYPE_CURRENT isn't available, this seems to work
             )
         STARTUP_PATH=startupdirectory()
-        bat_path=os.path.join(STARTUP_PATH,'.bat')
+        bat_path=os.path.join(STARTUP_PATH,'pywinschedule_watch.bat')
         print('Writing to %s'%(bat_path))
         with open(bat_path,'w') as f:
             f.write('pywinschedule watch %s'%(path))
